==> jc-1.4.0.tar.gz: javax/swing/plaf/BorderUIResource__24EmptyBorderUIResource.h <==
// public class javax.swing.plaf.BorderUIResource$EmptyBorderUIResource

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 564dabb34efb5ce6 javax_swing_border_AbstractBorder
// @dep_class a25a7c61707145e8 javax_swing_border_EmptyBorder
// @dep_class 3ac7f6ebcf73b3bd javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource

// header file dependencies
// @dep_header javax_swing_border_EmptyBorder

#include "javax/swing/border/EmptyBorder.h"

#ifndef _JC_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource_H_
#define _JC_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource_H_

// Forward structure declarations
struct _jc_java_awt_Insets$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$sub_refs	_jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$sub_refs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$sub_nonrefs	_jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$refs	_jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$refs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$nonrefs	_jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$nonrefs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$object	_jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$object;

typedef struct _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$fields_struct	_jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$fields_struct;
typedef const struct _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$vmethods	_jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$vmethods;
typedef const struct _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$vtable	_jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$vtable;
typedef const struct _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$vtype	_jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$fields_struct _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$method$_init$b5870f7bfece007a(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$object *, jint, jint, jint, jint);
extern void _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$method$_init$20cee96a25a472b6(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$object *, struct _jc_java_awt_Insets$object *);

// Virtual methods structure
struct _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_border_AbstractBorder$vmethods	javax_swing_border_AbstractBorder;
	_jc_javax_swing_border_EmptyBorder$vmethods	javax_swing_border_EmptyBorder;
	_jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$vmethods	javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource;
};

// Vtype
struct _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$refs {
    _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$sub_refs	javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource;
    _jc_javax_swing_border_EmptyBorder$sub_refs	javax_swing_border_EmptyBorder;
    _jc_javax_swing_border_AbstractBorder$sub_refs	javax_swing_border_AbstractBorder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_border_AbstractBorder$sub_nonrefs	javax_swing_border_AbstractBorder;
    _jc_javax_swing_border_EmptyBorder$sub_nonrefs	javax_swing_border_EmptyBorder;
    _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$sub_nonrefs	javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource;
};

// Object instance structure
struct _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$object {
	_jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$vtype	*vtype;
	_jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$vtype _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$class_object;

#endif	/* _JC_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/BorderUIResource__24EmptyBorderUIResource.h <==
// public class javax.swing.plaf.BorderUIResource$EmptyBorderUIResource

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 564dabb34efb5ce6 javax_swing_border_AbstractBorder
// @dep_class a25a7c61707145e8 javax_swing_border_EmptyBorder
// @dep_class 3ac7f6ebcf73b3bd javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource

// header file dependencies
// @dep_header javax_swing_border_EmptyBorder

#include "javax/swing/border/EmptyBorder.h"

#ifndef _JC_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource_H_
#define _JC_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource_H_

// Forward structure declarations
struct _jc_java_awt_Insets$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$sub_refs	_jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$sub_refs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$sub_nonrefs	_jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$refs	_jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$refs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$nonrefs	_jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$nonrefs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$object	_jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$object;

typedef struct _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$fields_struct	_jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$fields_struct;
typedef const struct _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$vmethods	_jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$vmethods;
typedef const struct _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$vtable	_jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$vtable;
typedef const struct _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$vtype	_jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$fields_struct _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$method$_init$b5870f7bfece007a(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$method$_init$20cee96a25a472b6(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$object *, struct _jc_java_awt_Insets$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_border_AbstractBorder$vmethods	javax_swing_border_AbstractBorder;
	_jc_javax_swing_border_EmptyBorder$vmethods	javax_swing_border_EmptyBorder;
	_jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$vmethods	javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource;
};

// Vtype
struct _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$refs {
    _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$sub_refs	javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource;
    _jc_javax_swing_border_EmptyBorder$sub_refs	javax_swing_border_EmptyBorder;
    _jc_javax_swing_border_AbstractBorder$sub_refs	javax_swing_border_AbstractBorder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_border_AbstractBorder$sub_nonrefs	javax_swing_border_AbstractBorder;
    _jc_javax_swing_border_EmptyBorder$sub_nonrefs	javax_swing_border_EmptyBorder;
    _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$sub_nonrefs	javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource;
};

// Object instance structure
struct _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$object {
	_jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$vtype	*vtype;
	_jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$vtype _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource$class_object;

#endif	/* _JC_javax_swing_plaf_BorderUIResource__24EmptyBorderUIResource_H_ */
